summaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
-rw-r--r--packages/browser/src/methods/startAuthentication.ts5
1 files changed, 4 insertions, 1 deletions
diff --git a/packages/browser/src/methods/startAuthentication.ts b/packages/browser/src/methods/startAuthentication.ts
index ee401a1..a08e3a3 100644
--- a/packages/browser/src/methods/startAuthentication.ts
+++ b/packages/browser/src/methods/startAuthentication.ts
@@ -14,10 +14,13 @@ import { identifyAuthenticationError } from '../helpers/identifyAuthenticationEr
/**
* Begin authenticator "login" via WebAuthn assertion
*
* @param requestOptionsJSON Output from @simplewebauthn/server's generateAssertionOptions(...)
*/
export default async function startAuthentication(
requestOptionsJSON: PublicKeyCredentialRequestOptionsJSON,
+ supportBrowserAutofill = false,
): Promise<AuthenticationCredentialJSON> {
if (!browserSupportsWebauthn()) {
throw new Error('WebAuthn is not supported in this browser');
@@ -14,10 +14,13 @@ import { identifyAuthenticationError } from '../helpers/identifyAuthenticationEr
* Begin authenticator "login" via WebAuthn assertion
*
- * @param requestOptionsJSON Output from @simplewebauthn/server's generateAssertionOptions(...)
+ * @param requestOptionsJSON Output from **@simplewebauthn/server**'s generateAssertionOptions(...)
+ * @param supportBrowserAutofill Initialize conditional UI to enable logging in via browser
+ * autofill prompts
*/
export default async function startAuthentication(